@@ -137,7 +137,7 @@ class DatePickerWidget(object):
     Date Time picker from Eonasdan GitHub
 
     """
-    data_template = ('<div class="input-group date" id="datepicker">'
+    data_template = ('<div class="input-group date appbuilder_date" id="datepicker">'
                     '<span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span>'
                     '</span>'
                     '<input class="form-control" data-format="yyyy-MM-dd" %(text)s/>'
@@ -147,6 +147,8 @@ class DatePickerWidget(object):
     def __call__(self, field, **kwargs):
         kwargs.setdefault('id', field.id)
         kwargs.setdefault('name', field.name)
+        if not field.data:
+            field.data = ""
         template = self.data_template
 
         return HTMLString(template % {'text': html_params(type='text',
@@ -160,7 +162,7 @@ class DateTimePickerWidget(object):
     Date Time picker from Eonasdan GitHub
 
     """
-    data_template = ('<div class="input-group date" id="datetimepicker">'
+    data_template = ('<div class="input-group date appbuilder_datetime" id="datetimepicker">'
                     '<span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span>'
                     '</span>'
                     '<input class="form-control" data-format="yyyy-MM-dd hh:mm:ss" %(text)s/>'
@@ -170,6 +172,8 @@ class DateTimePickerWidget(object):
     def __call__(self, field, **kwargs):
         kwargs.setdefault('id', field.id)
         kwargs.setdefault('name', field.name)
+        if not field.data:
+            field.data = ""
         template = self.data_template
 
         return HTMLString(template % {'text': html_params(type='text',
@@ -185,6 +189,8 @@ class BS3TextFieldWidget(widgets.TextInput):
         kwargs['class'] = u'form-control'
         if field.label:
             kwargs['placeholder'] = field.label.text
+        if 'name_' in kwargs:
+            field.name = kwargs['name_']
         return super(BS3TextFieldWidget, self).__call__(field, **kwargs)
 
 class BS3TextAreaFieldWidget(widgets.TextArea):
@@ -208,6 +214,8 @@ class Select2Widget(widgets.Select):
         kwargs['class'] = u'my_select2'
         kwargs['style'] = u'width:250px'
         kwargs['data-placeholder'] = u'Select Value'
+        if 'name_' in kwargs:
+            field.name = kwargs['name_']
         return super(Select2Widget, self).__call__(field, **kwargs)
 
 class Select2ManyWidget(widgets.Select):
@@ -216,4 +224,6 @@ class Select2ManyWidget(widgets.Select):
         kwargs['style'] = u'width:250px'
         kwargs['data-placeholder'] = u'Select Value'
         kwargs['multiple'] = u'true'
+        if 'name_' in kwargs:
+            field.name = kwargs['name_']
         return super(Select2ManyWidget, self).__call__(field, **kwargs)
